def add(x, y):
    sum=x+y
    print('Sum of', x, '&', y, 'is', sum)

def sub(x, y):
    dif=x-y
    print('Difference of', x, '&', y, 'is', dif)

def mul(x, y):
    prod=x*y
    print('Product of', x, '&', y, 'is', prod)

def div(x, y):
    di=x/y
    print('Division of', x, '&', y, 'yields', di)